==> jc-1.4.0.tar.gz: java/io/InvalidClassException.h <==
// public class java.io.InvalidClassException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class eb60cf59bc393752 java_io_InvalidClassException
// @dep_class fd900dec397fa9a1 java_io_ObjectStreamException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_io_ObjectStreamException

#include "java/io/ObjectStreamException.h"

#ifndef _JC_java_io_InvalidClassException_H_
#define _JC_java_io_InvalidClassException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_InvalidClassException$sub_refs	_jc_java_io_InvalidClassException$sub_refs;
typedef struct _jc_java_io_InvalidClassException$sub_nonrefs	_jc_java_io_InvalidClassException$sub_nonrefs;
typedef struct _jc_java_io_InvalidClassException$refs	_jc_java_io_InvalidClassException$refs;
typedef struct _jc_java_io_InvalidClassException$nonrefs	_jc_java_io_InvalidClassException$nonrefs;
typedef struct _jc_java_io_InvalidClassException$object	_jc_java_io_InvalidClassException$object;

typedef struct _jc_java_io_InvalidClassException$fields_struct	_jc_java_io_InvalidClassException$fields_struct;
typedef const struct _jc_java_io_InvalidClassException$vmethods	_jc_java_io_InvalidClassException$vmethods;
typedef const struct _jc_java_io_InvalidClassException$vtable	_jc_java_io_InvalidClassException$vtable;
typedef const struct _jc_java_io_InvalidClassException$vtype	_jc_java_io_InvalidClassException$vtype;

// Class fields structure
struct _jc_java_io_InvalidClassException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_io_InvalidClassException$fields_struct _jc_java_io_InvalidClassException$class_fields;

// Constructors
extern void _jc_java_io_InvalidClassException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_InvalidClassException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_io_InvalidClassException$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_io_InvalidClassException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_io_InvalidClassException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_io_InvalidClassException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_io_InvalidClassException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_io_InvalidClassException$vmethods {
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_io_InvalidClassException$object *);
};

// Vtable
struct _jc_java_io_InvalidClassException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_io_ObjectStreamException$vmethods	java_io_ObjectStreamException;
	_jc_java_io_InvalidClassException$vmethods	java_io_InvalidClassException;
};

// Vtype
struct _jc_java_io_InvalidClassException$vtype {
	_jc_type			type;
	_jc_java_io_InvalidClassException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_InvalidClassException$sub_refs {
	struct _jc_java_lang_String$object	*classname;
};

// Reference instance fields (object)
struct _jc_java_io_InvalidClassException$refs {
    _jc_java_io_InvalidClassException$sub_refs	java_io_InvalidClassException;
    _jc_java_io_ObjectStreamException$sub_refs	java_io_ObjectStreamException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_InvalidClassException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_InvalidClassException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_io_ObjectStreamException$sub_nonrefs	java_io_ObjectStreamException;
    _jc_java_io_InvalidClassException$sub_nonrefs	java_io_InvalidClassException;
};

// Object instance structure
struct _jc_java_io_InvalidClassException$object {
	_jc_java_io_InvalidClassException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_InvalidClassException$vtype	*vtype;
	_jc_java_io_InvalidClassException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_InvalidClassException$vtype _jc_java_io_InvalidClassException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_InvalidClassException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_InvalidClassException$class_object;

#endif	/* _JC_java_io_InvalidClassException_H_ */

==> jc-1.4.6.tar.gz: java/io/InvalidClassException.h <==
// public class java.io.InvalidClassException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class eb60cf59bc393752 java_io_InvalidClassException
// @dep_class fd900dec397fa9a1 java_io_ObjectStreamException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_io_ObjectStreamException

#include "java/io/ObjectStreamException.h"

#ifndef _JC_java_io_InvalidClassException_H_
#define _JC_java_io_InvalidClassException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_InvalidClassException$sub_refs	_jc_java_io_InvalidClassException$sub_refs;
typedef struct _jc_java_io_InvalidClassException$sub_nonrefs	_jc_java_io_InvalidClassException$sub_nonrefs;
typedef struct _jc_java_io_InvalidClassException$refs	_jc_java_io_InvalidClassException$refs;
typedef struct _jc_java_io_InvalidClassException$nonrefs	_jc_java_io_InvalidClassException$nonrefs;
typedef struct _jc_java_io_InvalidClassException$object	_jc_java_io_InvalidClassException$object;

typedef struct _jc_java_io_InvalidClassException$fields_struct	_jc_java_io_InvalidClassException$fields_struct;
typedef const struct _jc_java_io_InvalidClassException$vmethods	_jc_java_io_InvalidClassException$vmethods;
typedef const struct _jc_java_io_InvalidClassException$vtable	_jc_java_io_InvalidClassException$vtable;
typedef const struct _jc_java_io_InvalidClassException$vtype	_jc_java_io_InvalidClassException$vtype;

// Class fields structure
struct _jc_java_io_InvalidClassException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_io_InvalidClassException$fields_struct _jc_java_io_InvalidClassException$class_fields;

// Constructors
extern void _jc_java_io_InvalidClassException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_InvalidClassException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_InvalidClassException$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_io_InvalidClassException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_io_InvalidClassException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_io_InvalidClassException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_InvalidClassException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_io_InvalidClassException$vmethods {
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_io_InvalidClassException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_InvalidClassException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_io_ObjectStreamException$vmethods	java_io_ObjectStreamException;
	_jc_java_io_InvalidClassException$vmethods	java_io_InvalidClassException;
};

// Vtype
struct _jc_java_io_InvalidClassException$vtype {
	_jc_type			type;
	_jc_java_io_InvalidClassException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_InvalidClassException$sub_refs {
	struct _jc_java_lang_String$object	*classname;
};

// Reference instance fields (object)
struct _jc_java_io_InvalidClassException$refs {
    _jc_java_io_InvalidClassException$sub_refs	java_io_InvalidClassException;
    _jc_java_io_ObjectStreamException$sub_refs	java_io_ObjectStreamException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_InvalidClassException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_InvalidClassException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_io_ObjectStreamException$sub_nonrefs	java_io_ObjectStreamException;
    _jc_java_io_InvalidClassException$sub_nonrefs	java_io_InvalidClassException;
};

// Object instance structure
struct _jc_java_io_InvalidClassException$object {
	_jc_java_io_InvalidClassException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_InvalidClassException$vtype	*vtype;
	_jc_java_io_InvalidClassException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_InvalidClassException$vtype _jc_java_io_InvalidClassException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_InvalidClassException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_InvalidClassException$class_object;

#endif	/* _JC_java_io_InvalidClassException_H_ */
